*******************************************************************
* Introduction to Stata 14 Graphics - Dawn Koffman - September 2016
*******************************************************************

* slide 10 - Overlaying Two-Way Plot Types
****************8*************************
sysuse uslifeexp.dta, clear
#delimit ;
scatter le_male le_female year if year >= 1950
|| lfit le_male   year if year >= 1950
|| lfit le_female year if year >= 1950;
#delimit cr

* slide 11 - Adding a Title and Removing the Legend
***************************************************
sysuse uslifeexp.dta, clear
#delimit ;
scatter le_male le_female year if year >= 1950
|| lfit le_male   year if year >= 1950
|| lfit le_female year if year >= 1950
,title("US Male and Female Life Expectancy, 1950-2000")
 text(75 1978 "Female", place(3))
 text(68 1978 "Male", place(3))
 legend(off);
#delimit cr

* slide 12 - Showing Confidence Intervals, Labelling Axes, Modifyng Legend
**************************************************************************
sysuse lifeexp.dta, clear
#delimit ;
twoway
 (lfitci  lexp safewater if region == 2) /* North America */
 (scatter lexp safewater if region == 2)
,title("Life expectancy at birth by access to safe water, 1998") 
 ytitle("Life expectancy at birth")
 xtitle("Percent of population with access to safe water")
 legend(ring(0) pos(5) order(2 "Linear fit" 1 "95% CI"));
#delimit cr

* slide 13 - Marker Labels and Subtitles
****************************************
sysuse lifeexp.dta, clear
#delimit ;
twoway
 (lfitci  lexp safewater if region == 2) /* North America */
 (scatter lexp safewater if region == 2, mlabel(country))
,title("Life expectancy at birth by access to safe water, 1998")
 subtitle("North America")  
 ytitle("Life expectancy at birth")
 xtitle("Percent of population with access to safe water")
 legend(ring(0) pos(5) order(2 "Linear fit" 1 "95% CI"));
#delimit cr

* slide 14 - Position of Marker Labels
**************************************
sysuse lifeexp.dta, clear
generate pos = 12 if country == "Panama"
replace  pos = 12 if country == "Honduras"
replace  pos = 10 if country == "Cuba"
replace  pos =  9 if country == "Jamaica"
replace  pos =  9 if country == "El Salvador"
replace  pos =  9 if country == "Trinidad and Tobago"
replace  pos =  9 if country == "Dominican Republic"
#delimit ;
twoway
 (lfitci  lexp safewater if region == 2) /* North America */
 (scatter lexp safewater if region == 2
  , mlabel(country) mlabvposition(pos))
,title("Life expectancy at birth by access to safe water, 1998")
 subtitle("North America")  
 ytitle("Life expectancy at birth")
 xtitle("Percent of population with access to safe water")
 legend(ring(0) pos(5) order(2 "Linear fit" 1 "95% CI"))
 plotregion(margin(r+10));
#delimit cr

* slide 15 - Position of Marker Labels
**************************************
sysuse lifeexp.dta, clear
#delimit ;
twoway
 (scatter lexp safewater if region == 2 | region == 3
  ,mlabel(country))
 ,title("Life expectancy at birth by access to safe water, 1998")
 subtitle("North and South America")  
 ytitle("Life expectancy at birth")
 xtitle("Percent of population with access to safe water")
 plotregion(margin(r+10));
#delimit cr

* slide 16 - Position of Marker Labels and Legend Display
*********************************************************
sysuse lifeexp.dta, clear
generate pos =  3
replace  pos =  9 if country == "Argentina"
replace  pos =  9 if country == "Canada"
replace  pos =  9 if country == "Cuba"
replace  pos =  9 if country == "Panama"
replace  pos =  9 if country == "Venezuela"
replace  pos =  9 if country == "Jamaica"
replace  pos =  9 if country == "Dominican Republic"
replace  pos =  9 if country == "Ecuador"
replace  pos =  9 if country == "El Salvador"
replace  pos = 12 if country == "Puerto Rico"
#delimit ;
twoway
 (scatter lexp safewater if region == 2
  ,mlabel(country) mlabvposition(pos))
 (scatter lexp safewater if region == 3
  ,mlabel(country) mlabvposition(pos))
,title("Life expectancy at birth by access to safe water, 1998")
 subtitle("North and South America")  
 ytitle("Life expectancy at birth")
 xtitle("Percent of population with access to safe water")
 legend(ring(0) pos(5) order(1 "North America" 2 "South America") cols(1));
#delimit cr

* slide 17 - Marker Size and Symbol, Line Color 
***********************************************
sysuse lifeexp.dta, clear
generate pos =  3
replace  pos =  9 if country == "Argentina"
replace  pos =  9 if country == "Canada"
replace  pos =  9 if country == "Cuba"
replace  pos =  9 if country == "Panama"
replace  pos =  9 if country == "Venezuela"
replace  pos =  9 if country == "Jamaica"
replace  pos =  9 if country == "Dominican Republic"
replace  pos =  9 if country == "Ecuador"
replace  pos =  9 if country == "El Salvador"
replace  pos = 12 if country == "Puerto Rico"
#delimit ;
twoway
 (scatter lexp safewater if region == 2
  ,mlabel(country) mlabvposition(pos) msize(small))
 (scatter lexp safewater if region == 3
  ,mlabel(country) mlabvposition(pos) msize(small) msymbol(circle_hollow))
(lfit lexp safewater if region == 2, clcolor(navy))
(lfit lexp safewater if region == 3, clcolor(maroon))
,title("Life expectancy at birth by access to safe water, 1998")
 subtitle("North and South America")  
 ytitle("Life expectancy at birth")
 xtitle("Percent of population with access to safe water")
 legend(ring(0) pos(5) cols(1) order(1 "North America" 2 "South America" 
   3 "North America linear fit" 4 "South America linear fit"));
#delimit cr

* slide 18 - Marker and Marker Label Color, Line Style 
******************************************************
sysuse lifeexp.dta, clear
generate pos =  3
replace  pos =  9 if country == "Argentina"
replace  pos =  9 if country == "Canada"
replace  pos =  9 if country == "Cuba"
replace  pos =  9 if country == "Panama"
replace  pos =  9 if country == "Venezuela"
replace  pos =  9 if country == "Jamaica"
replace  pos =  9 if country == "Dominican Republic"
replace  pos =  9 if country == "Ecuador"
replace  pos =  9 if country == "El Salvador"
replace  pos = 12 if country == "Puerto Rico"
#delimit ;
twoway
 (scatter lexp safewater if region == 2
  ,mlabel(country) mlabvposition(pos) msize(small) mcolor(black) mlabcolor(black))
 (scatter lexp safewater if region == 3
  ,mlabel(country) mlabvposition(pos) msize(small) mcolor(black) mlabcolor(black)
   msymbol(circle_hollow))
(lfit lexp safewater if region == 2, clcolor(black))
(lfit lexp safewater if region == 3, clcolor(black) clpattern(dash))
,title("Life expectancy at birth by access to safe water, 1998", color(black))
 subtitle("North and South America")  
 ytitle("Life expectancy at birth")
 xtitle("Percent of population with access to safe water")
 legend(ring(0) pos(5) cols(1) order(1 "North America" 2 "South America" 
   3 "North America linear fit" 4 "South America linear fit"));
#delimit cr

* slide 19 - By-Graph: Separate Graphs for Each Subset of Data
**************************************************************
sysuse lifeexp.dta, clear
#delimit ;
twoway scatter lexp safewater, by(region, total)
,ytitle("Life expectancy at birth")
 xtitle("Percent of population with access to safe water");
#delimit cr

* slide 20 - By-Graph Options
*****************************
sysuse lifeexp.dta, clear
#delimit ;
twoway scatter lexp safewater
,by(region,total style(compact) 
    title("Life expectancy by access to safe water") note(""))
 ytitle("Life expectancy at birth")
 xtitle("Percent of population with access to safe water");
#delimit cr

* slide 21 - Axis Scale, Ticks and Labels
*****************************************
sysuse lifeexp.dta, clear
#delimit ;
twoway scatter lexp safewater
, by(region,total style(compact)
     title("Life expectancy by access to safe water") note(""))
 xscale(range(20 100))
 xtick(20(10)100)
 xlabel(30(10)100, labsize(small))
 xtitle("Percent of population with access to safe water")
 ytitle("Life expectancy at birth")
 ylabel(55(5)80, angle(0));
#delimit cr

* slide 22 - Storing Graphs in Memory
*************************************
sysuse lifeexp.dta, clear
generate  pos =  3
replace   pos =  6 if country == "Honduras"
replace   pos =  9 if country == "Canada"
replace   pos =  9 if country == "Cuba"
replace   pos =  9 if country == "Guatemala"
replace   pos =  9 if country == "Panama"
replace   pos =  9 if country == "Jamaica"
replace   pos =  9 if country == "Dominican Republic"
replace   pos =  9 if country == "Ecuador"
replace   pos =  9 if country == "El Salvador"
replace   pos = 12 if country == "Puerto Rico"
#delimit ;
twoway 
 (scatter lexp safewater if region == 2,
  mcolor(black) msize(small) 
  mlabel(country) mlabvposition(pos) mlabcolor(black))
 (lfit lexp safewater if region == 2, clcolor(black))
,name(north_america, replace)
 subtitle("North America", color(black))
 ylabel(,angle(0)) 
 ytitle("Life expectancy at birth")
 xtitle("Percent of population with access to safe water")
 legend(off);
#delimit cr

* slide 23 - Storing Graphs in Memory *** First create named graph on slide 22
******************************************************************************
replace  pos = 9 if country == "Venezuela"
replace  pos = 9 if country == "Argentina"
replace  pos = 9 if country == "Ecuador"
#delimit ;
twoway 
 (scatter lexp safewater if region == 3,
  mcolor(black) msize(small) 
  mlabel(country) mlabvposition(pos) mlabcolor(black))
 (lfit lexp safewater if region == 3, clcolor(black))
,name(south_america, replace)
 subtitle("South America", color(black))
 ylabel(, angle(0)) 
 ytitle("Life expectancy at birth")
 xtitle("Percent of population with access to safe water")
 legend(off);
#delimit cr

* slide 24 - Combining Graphs  *** Requires named graphs created on slides 22 and 23
************************************************************************************
#delimit ;
graph combine north_america south_america
,title("Life expectancy by access to safe water", color(black)) col(1);
#delimit cr

* slide 25 - Combining Graphs  *** Requires named graphs created on slides 21 and 22
************************************************************************************
#delimit ;
graph combine north_america south_america
,title("Life expectancy by access to safe water",
 color(black))
 xcommon ycommon
 xsize(7) ysize(10.5)
 col(1);
#delimit cr

